valuta library

Classes

CurrencyConverter
ExchangeRateProvider
FrankFurterExchangeRateProvider
A free exchange rate provider that uses the Frankfurter API (https://frankfurter.app/). Frankfurter is a free, open-source currency data API that tracks reference exchange rates published by institutional and non-commercial sources like the European Central Bank. No usage caps or API keys. Works great client-side in the browser or mobile apps. The public API is available at api.frankfurter.dev. If preferred, you can self-host.
Money
Rate
Custom Rate Provider

Enums

Currency